package com.tistory.whdghks913.croutonhelper;

import android.app.Activity;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import de.keyboardsurfer.android.widget.crouton.Configuration;
import de.keyboardsurfer.android.widget.crouton.Crouton;
import de.keyboardsurfer.android.widget.crouton.Style;
import de.keyboardsurfer.android.widget.crouton.Style.Builder;

public class CroutonHelper {
    private Activity mActivity;
    private Crouton mCrouton;

    private int viewID = 0;
    private View mView = null;
    private ViewGroup mViewGroup = null;

    private Configuration.Builder ConfigurationBuilder;
    private Builder CroutonStyle;
    private OnClickListener clickListener;

    public final int MODE_DEFAULT = 0;
    public final int MODE_CUSTOM_VIEW = 1;
    private int MODE = MODE_DEFAULT;

    private String croutonText = "";
    private final String aboutHelper = "http://whdghks913.tistory.com, Version v1.0";

    public CroutonHelper(Activity mActivity) {
        this.mActivity = mActivity;
        CroutonStyle = new Builder(Style.INFO);
        ConfigurationBuilder = new Configuration.Builder();
    }

    /**
     * Text ϱ - String
     */
    public void setText(String croutonText) {
        this.croutonText = croutonText;
    }

    /**
     * Text ϱ - R.string.xx
     */
    public void setText(int resId) {
        croutonText = mActivity.getString(resId);
    }

    /**
     * Crouton ǥ ð  - (String) иƮ
     */
    public void setDuration(String duration) {
        if (!"".equals(duration)) {
            try {
                int croutonDuration = Integer.parseInt(duration);
                setDuration(croutonDuration);
            } catch (Exception ex) {
                ex.printStackTrace();
            }
        }
    }

    /**
     * Crouton ǥ ð  - (int) иƮ
     */
    public void setDuration(int duration) {
        if (duration != 0)
            ConfigurationBuilder.setDuration(duration);
    }

    /**
     * Crouton ⺻ ǥ ð 
     * 
     * true : Toast.LENGTH_LONG, false : Toast.LENGTH_SHORT
     */

    public void setDuration(boolean croutonLong) {
        if (croutonLong)
            ConfigurationBuilder.setDuration(Configuration.DURATION_LONG);
        else
            ConfigurationBuilder.setDuration(Configuration.DURATION_SHORT);
    }

    /**
     * Crouton ǥ ð  - ġؾ 
     */
    public void setInfinity(boolean setInfinity) {
        if (setInfinity)
            ConfigurationBuilder.setDuration(Configuration.DURATION_INFINITE);
        else
            ConfigurationBuilder.setDuration(Configuration.DURATION_SHORT);
    }

    /**
     * Crouton ǥõ ViewGroup 
     * 
     *  setViewResId() ʱȭ
     */
    public void setViewGroup(ViewGroup viewGroup) {
        if (viewGroup != null) {
            mViewGroup = viewGroup;
            viewID = 0;
        }
    }

    /**
     * Crouton ǥõ View Id 
     * 
     *  setViewGroup() ʱȭ
     */
    public void setViewResId(int resID) {
        if (resID != 0) {
            viewID = resID;
            mViewGroup = null;
        }
    }

    /**
     * Ŀ   - View
     */
    public void setCustomView(View view) {
        if (view != null) {
            mView = view;
            setMode(MODE_CUSTOM_VIEW);
        }
    }

    /**
     * Ŀ   - R.layout.xx
     */
    public void setCustomView(int customViewId) {
        if (customViewId != 0) {
            mView = mActivity.getLayoutInflater().inflate(customViewId, null);
            setMode(MODE_CUSTOM_VIEW);
        }
    }

    /**
     * Ÿ 
     * 
     * Style.ALERT : , Style.CONFIRM : ʷϻ, Style.INFO : Ķ
     */
    public void setStyle(Style style) {
        if (style != null)
            if (style == Style.ALERT)
                CroutonStyle.setBackgroundColorValue(Style.holoRedLight);
            else if (style == Style.CONFIRM)
                CroutonStyle.setBackgroundColorValue(Style.holoGreenLight);
            else if (style == Style.INFO)
                CroutonStyle.setBackgroundColorValue(Style.holoBlueLight);
    }

    /**
     *  
     * 
     * Ŀ 並  Crouton  Ȯ
     */
    public void setMode(int mode) {
        if (mode == MODE_DEFAULT)
            MODE = MODE_DEFAULT;
        else if (mode == MODE_CUSTOM_VIEW)
            MODE = MODE_CUSTOM_VIEW;
    }

    /**
     * Text   - int
     */
    public void setTextColor(int textColor) {
        if (textColor != 0) {
            CroutonStyle.setTextColorValue(textColor);
        }
    }

    /**
     * Text   - String (ڵ String int ȯ)
     */
    public void setTextColor(String textColor) {
        try {
            if (!"".equals(textColor))
                CroutonStyle.setTextColorValue(Color.parseColor(textColor));
        } catch (IllegalArgumentException ex) {
            ex.printStackTrace();
        }
    }

    /**
     * Text   - R.color.xx
     */
    public void setTextColorResource(int textColor) {
        if (textColor != 0)
            CroutonStyle.setTextColor(textColor);
    }

    /**
     * Text ũ  - sp
     */
    public void setTextSize(int textSize) {
        if (textSize != 0)
            CroutonStyle.setTextSize(textSize);
    }

    /**
     * TextAppearance 
     * 
     * android.R.attr.textAppearanceLarge android.R.attr.textAppearanceMedium
     * android.R.attr.textAppearanceSmall
     */
    public void setTextAppearance(int textAppearanceResId) {
        if (textAppearanceResId != 0)
            CroutonStyle.setTextAppearance(textAppearanceResId);
    }

    /**
     * ׶ ÷  - int
     */
    public void setBackgroundColor(int bgColorResId) {
        if (bgColorResId != 0)
            CroutonStyle.setBackgroundColorValue(bgColorResId);
    }

    /**
     * ׶ ÷  - String (Color.parseColor)
     * 
     * @param bgColor
     */
    public void setBackgroundColor(String bgColor) {
        try {
            if (!"".equals(bgColor))
                CroutonStyle.setBackgroundColorValue(Color.parseColor(bgColor));
        } catch (IllegalArgumentException ex) {
            ex.printStackTrace();
        }
    }

    /**
     * ׶ ÷  - R.color.xx
     */
    public void setBackgroundColorResource(int bgColorResId) {
        if (bgColorResId != 0)
            CroutonStyle.setBackgroundColor(bgColorResId);
    }

    /**
     * ׶ ̹  - R.drawable.xx
     */
    public void setBackgroundDrawable(int bgDrawableResId) {
        if (bgDrawableResId != 0)
            CroutonStyle.setBackgroundDrawable(bgDrawableResId);
    }

    /**
     * Text ġ 
     * 
     * Gravity.CENTER, Gravity.CENTER_VERTICAL, Gravity.CENTER_HORIZONTAL,
     * Gravity.BOTTOM, Gravity.TOP, Gravity.LEFT, Gravity.RIGHT 
     */
    public void setGravity(int gravity) {
        if (gravity != 0)
            CroutonStyle.setGravity(gravity);
    }

    /**
     * Crouton 
     */
    public void setHeight(int height) {
        if (height != 0)
            CroutonStyle.setHeight(height);
    }

    /**
     * Crouton ̹ ߰ - Drawable
     * 
     * Ŀ (X)
     */
    public void setImageDrawable(Drawable imageDrawable) {
        if (imageDrawable != null)
            CroutonStyle.setImageDrawable(imageDrawable);
    }

    /**
     * Crouton ̹ ߰ - R.drawable.xx
     */
    public void setImageResource(int imageResId) {
        if (imageResId != 0)
            CroutonStyle.setImageResource(imageResId);
    }

    /**
     * Crouton  ¿ 
     */
    public void setPaddingDimensionResId(int paddingResId) {
        if (paddingResId != 0)
            CroutonStyle.setPaddingDimensionResId(paddingResId);
    }

    // public void setPaddingInPixels(int padding) {
    // CroutonStyle.setPaddingInPixels(padding);
    // }

    /**
     * ġϸ 
     */
    public void setAutoTouchCancle(boolean autocancle) {
        if (autocancle) {
            OnClickListener listener = new OnClickListener() {

                @Override
                public void onClick(View v) {
                    hide();
                }
            };
            setOnClickListener(listener);
        } else {
            setOnClickListener(null);
        }
    }

    /**
     * Crouton 
     * 
     * true :  . false : Helper 
     */
    public void cancle(boolean allCancle) {
        if (allCancle)
            Crouton.cancelAllCroutons();
        else
            mCrouton.cancel();
    }

    /**
     * Crouton 
     */
    public void hide() {
        Crouton.hide(mCrouton);
    }

    /**
     * ƼƼ Crouton 
     */
    public void clearCroutonsForActivity() {
        Crouton.clearCroutonsForActivity(mActivity);
    }

    /**
     * ClickListener 
     */
    public void setOnClickListener(OnClickListener clickListener) {
        if (clickListener != null)
            this.clickListener = clickListener;
    }

    public boolean show() {
        Style mStyle = CroutonStyle.build();
        Configuration croutonConfiguration = ConfigurationBuilder.build();

        if (MODE == MODE_DEFAULT) {

            if (viewID == 0 && mViewGroup == null)
                mCrouton = Crouton.makeText(mActivity, croutonText, mStyle)
                        .setConfiguration(croutonConfiguration);
            else if (viewID != 0)
                mCrouton = Crouton.makeText(mActivity, croutonText, mStyle,
                        viewID).setConfiguration(croutonConfiguration);
            else if (mViewGroup != null)
                mCrouton = Crouton.makeText(mActivity, croutonText, mStyle,
                        mViewGroup).setConfiguration(croutonConfiguration);
            else
                return false;

        } else if (MODE == MODE_CUSTOM_VIEW) {
            if (mView == null) {
                return false;
            }

            if (mViewGroup != null)
                mCrouton = Crouton.make(mActivity, mView, mViewGroup);
            else
                mCrouton = Crouton.make(mActivity, mView, viewID,
                        croutonConfiguration);
        }

        if (clickListener != null) {
            if (mView != null)
                mView.setOnClickListener(clickListener);
            else if (mViewGroup != null)
                mViewGroup.setOnClickListener(clickListener);
            else
                mCrouton.setOnClickListener(clickListener);
        }

        mCrouton.show();

        return true;
    }

    public String getLisence() {
        return Crouton.getLicenseText();
    }

    public String aboutHelper() {
        return aboutHelper;
    }

    public Crouton getCrouton() {
        return mCrouton;
    }

    public Builder getCroutonStyle() {
        return CroutonStyle;
    }
}
